@@ -210,7 +210,7 @@ shishi_authenticator_to_file (Shishi * handle, Shishi_asn1 authenticator,
 
   res = fclose (fh);
   if (res != 0)
-    return SHISHI_FCLOSE_ERROR;
+    return SHISHI_IO_ERROR;
 
   if (VERBOSE (handle))
     printf (_("Writing Authenticator to %s...done\n"), filename);
@@ -293,7 +293,7 @@ shishi_authenticator_from_file (Shishi * handle, Shishi_asn1 * authenticator,
 
   res = fclose (fh);
   if (res != 0)
-    return SHISHI_FCLOSE_ERROR;
+    return SHISHI_IO_ERROR;
 
   if (VERBOSE (handle))
     printf (_("Reading Authenticator from %s...done\n"), filename);
