@@ -34,8 +34,8 @@ struct shishi_error_msgs _shishi_error_messages[] = {
    "Error in ASN.1 data, probably due to corrupt data."},
   {SHISHI_FOPEN_ERROR,
    "Could not open file."},
-  {SHISHI_FCLOSE_ERROR,
-   "Could not close file."},
+  {SHISHI_IO_ERROR,
+   "File input/output error."},
   {SHISHI_MALLOC_ERROR,
    "Memory allocation error in shishi library."},
   {SHISHI_BASE64_ERROR,
