@@ -171,7 +171,7 @@ shishi_kdcrep_to_file (Shishi * handle, Shishi_asn1 kdcrep,
 
   res = fclose (fh);
   if (res != 0)
-    return SHISHI_FCLOSE_ERROR;
+    return SHISHI_IO_ERROR;
 
   if (VERBOSE (handle))
     printf (_("Writing KDC-REP to %s...done\n"), filename);
@@ -251,7 +251,7 @@ shishi_kdcrep_from_file (Shishi * handle, Shishi_asn1 * kdcrep,
 
   res = fclose (fh);
   if (res != 0)
-    return SHISHI_FCLOSE_ERROR;
+    return SHISHI_IO_ERROR;
 
   if (VERBOSE (handle))
     printf (_("Reading KDC-REP from %s...done\n"), filename);
