@@ -299,7 +299,7 @@ shishi_safe_to_file (Shishi * handle, Shishi_asn1 safe,
 
   res = fclose (fh);
   if (res != 0)
-    return SHISHI_FCLOSE_ERROR;
+    return SHISHI_IO_ERROR;
 
   if (VERBOSE (handle))
     printf (_("Writing SAFE to %s...done\n"), filename);
@@ -379,7 +379,7 @@ shishi_safe_from_file (Shishi * handle, Shishi_asn1 * safe,
 
   res = fclose (fh);
   if (res != 0)
-    return SHISHI_FCLOSE_ERROR;
+    return SHISHI_IO_ERROR;
 
   if (VERBOSE (handle))
     printf (_("Reading SAFE from %s...done\n"), filename);
