@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.20"
+#define SHISHI_VERSION "0.0.21"
 
 /* Error codes */
 typedef enum
@@ -35,7 +35,7 @@ typedef enum
   SHISHI_OK = 0,
   SHISHI_ASN1_ERROR = 1,
   SHISHI_FOPEN_ERROR = 2,
-  SHISHI_FCLOSE_ERROR = 3,
+  SHISHI_IO_ERROR = 3,
   SHISHI_MALLOC_ERROR = 4,
   SHISHI_BASE64_ERROR = 5,
   SHISHI_REALM_MISMATCH = 6,
