@@ -54,7 +54,7 @@ test (Shishi * handle)
   Shishi_asn1 a;
   char buffer[BUFSIZ];
   char buffer2[BUFSIZ];
-  char *p;
+  char *p, *buf, *buf2;
   int res;
   size_t n, m;
   int32_t t;
@@ -120,16 +120,18 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_client_set() failed\n");
 
-  /* shishi_authenticator_cname_get */
-  n = sizeof (buffer);
-  res = shishi_authenticator_cname_get (handle, a, buffer, &n);
+  /* shishi_authenticator_client */
+  res = shishi_authenticator_client (handle, a, &buf, &n);
   if (debug)
-    escapeprint (buffer, n);
+    escapeprint (buf, n);
   if (res == SHISHI_OK &&
-      n == strlen ("foo/bar/baz") && memcmp (buffer, "foo/bar/baz", n) == 0)
-    success ("shishi_authenticator_cname_get() OK\n");
+      n == strlen ("foo/bar/baz") && memcmp (buf, "foo/bar/baz", n) == 0)
+    {
+      success ("shishi_authenticator_client() OK\n");
+      free (buf);
+    }
   else
-    fail ("shishi_authenticator_cname_get() failed\n");
+    fail ("shishi_authenticator_client() failed\n");
 
   /* shishi_authenticator_client_set */
   res = shishi_authenticator_client_set (handle, a, "foo");
@@ -138,16 +140,17 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_client_set() failed\n");
 
-  /* shishi_authenticator_cname_get */
-  n = sizeof (buffer);
-  res = shishi_authenticator_cname_get (handle, a, buffer, &n);
+  /* shishi_authenticator_client */
+  res = shishi_authenticator_client (handle, a, &buf, &n);
   if (debug)
-    escapeprint (buffer, n);
-  if (res == SHISHI_OK && n == strlen ("foo")
-      && memcmp (buffer, "foo", n) == 0)
-    success ("shishi_authenticator_cname_get() OK\n");
+    escapeprint (buf, n);
+  if (res == SHISHI_OK && n == strlen ("foo") && memcmp (buf, "foo", n) == 0)
+    {
+      success ("shishi_authenticator_client() OK\n");
+      free (buf);
+    }
   else
-    fail ("shishi_authenticator_cname_get() failed\n");
+    fail ("shishi_authenticator_client() failed\n");
 
   /* shishi_authenticator_set_crealm */
   res = shishi_authenticator_set_crealm (handle, a, "bar");
@@ -156,16 +159,18 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_set_crealm() failed\n");
 
-  /* shishi_authenticator_cnamerealm_get */
-  n = sizeof (buffer);
-  res = shishi_authenticator_cnamerealm_get (handle, a, buffer, &n);
+  /* shishi_authenticator_clientrealm */
+  res = shishi_authenticator_clientrealm (handle, a, &buf, &n);
   if (debug)
-    escapeprint (buffer, n);
+    escapeprint (buf, n);
   if (res == SHISHI_OK &&
-      n == strlen ("foo@bar") && memcmp (buffer, "foo@bar", n) == 0)
-    success ("shishi_authenticator_cnamerealm_get() OK\n");
+      n == strlen ("foo@bar") && memcmp (buf, "foo@bar", n) == 0)
+    {
+      success ("shishi_authenticator_clientrealm() OK\n");
+      free (buf);
+    }
   else
-    fail ("shishi_authenticator_cnamerealm_get() failed\n");
+    fail ("shishi_authenticator_clientrealm() failed\n");
 
   /* shishi_authenticator_add_authorizationdata */
   res = shishi_authenticator_add_authorizationdata (handle, a, 42, "baz", 3);
@@ -175,18 +180,20 @@ test (Shishi * handle)
     fail ("shishi_authenticator_add_authorizationdata() failed\n");
 
   /* shishi_authenticator_authorizationdata */
-  m = sizeof (buffer);
-  res = shishi_authenticator_authorizationdata (handle, a, &t, buffer, &m, 1);
+  res = shishi_authenticator_authorizationdata (handle, a, &t, &buf, &m, 1);
   if (debug)
-    escapeprint (buffer, m);
-  if (res == SHISHI_OK && t == 42 && m == 3 && memcmp (buffer, "baz", 3) == 0)
+    escapeprint (buf, m);
+  if (res == SHISHI_OK && t == 42 && m == 3 && memcmp (buf, "baz", 3) == 0)
     success ("shishi_authenticator_authorizationdata() OK\n");
   else
     fail ("shishi_authenticator_authorizationdata() failed\n");
+  if (res == SHISHI_OK)
+    free (buf);
 
   /* shishi_authenticator_authorizationdata */
-  m = sizeof (buffer);
-  res = shishi_authenticator_authorizationdata (handle, a, &t, buffer, &m, 2);
+  res = shishi_authenticator_authorizationdata (handle, a, &t, &buf, &m, 2);
+  if (res == SHISHI_OK)
+    free (buf);
   if (res == SHISHI_OUT_OF_RANGE)
     success ("shishi_authenticator_authorizationdata() OK\n");
   else
@@ -199,13 +206,12 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_remove_cksum() failed\n");
 
-  /* shishi_a2d */
-  n = sizeof (buffer);
-  res = shishi_a2d (handle, a, buffer, &n);
+  /* shishi_asn1_to_der */
+  res = shishi_asn1_to_der (handle, a, &buf, &n);
   if (res == SHISHI_OK)
-    success ("shishi_a2d() OK\n");
+    success ("shishi_asn1_to_der() OK\n");
   else
-    n = 0, fail ("shishi_a2d() failed\n");
+    n = 0, fail ("shishi_asn1_to_der() failed\n");
 
   /* shishi_authenticator_to_file */
   res = shishi_authenticator_to_file (handle, a, SHISHI_FILETYPE_TEXT,
@@ -239,20 +245,22 @@ test (Shishi * handle)
 	fail ("shishi_authenticator_print() failed\n");
     }
 
-  /* shishi_a2d */
-  m = sizeof (buffer2);
-  res = shishi_a2d (handle, a, buffer2, &m);
+  /* shishi_asn1_to_der */
+  res = shishi_asn1_to_der (handle, a, &buf2, &m);
   if (res == SHISHI_OK)
-    success ("shishi_a2d() OK\n");
+    success ("shishi_asn1_to_der() OK\n");
   else
-    n = 0, fail ("shishi_a2d() failed\n");
+    n = 0, fail ("shishi_asn1_to_der() failed\n");
 
   /* Compare DER encodings of authenticators */
-  if (n > 0 && m > 0 && n == m && memcmp (buffer, buffer2, n) == 0)
+  if (n > 0 && m > 0 && n == m && memcmp (buf, buf2, n) == 0)
     success ("DER comparison OK\n");
   else
     fail ("DER comparison failed\n");
 
+  free (buf);
+  free (buf2);
+
   /* shishi_authenticator_cusec_set */
   res = shishi_authenticator_cusec_set (handle, a, 4711);
   if (res == SHISHI_OK)
@@ -285,27 +293,28 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_ctime() failed\n");
 
-  /* shishi_a2d */
-  n = sizeof (buffer);
-  res = shishi_a2d (handle, a, buffer, &n);
+  /* shishi_asn1_to_der */
+  res = shishi_asn1_to_der (handle, a, &buf, &n);
   if (res == SHISHI_OK)
-    success ("shishi_a2d() OK\n");
+    success ("shishi_asn1_to_der() OK\n");
   else
-    n = 0, fail ("shishi_a2d() failed\n");
+    n = 0, fail ("shishi_asn1_to_der() failed\n");
   if (debug)
     {
       shishi_authenticator_print (handle, stdout, a);
-      hexprint (buffer, n);
+      hexprint (buf, n);
       puts ("");
       hexprint (authenticator, sizeof (authenticator));
       puts ("");
     }
   if (n == sizeof (authenticator) &&
-      n == AUTHENTICATOR_LEN && memcmp (authenticator, buffer, n) == 0)
+      n == AUTHENTICATOR_LEN && memcmp (authenticator, buf, n) == 0)
     success ("DER comparison OK\n");
   else
     fail ("DER comparison failed\n");
 
+  free (buf);
+
   /* shishi_authenticator_clear_authorizationdata */
   res = shishi_authenticator_clear_authorizationdata (handle, a);
   if (res == SHISHI_OK)
@@ -313,27 +322,28 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_clear_authorizationdata() failed\n");
 
-  /* shishi_a2d */
-  n = sizeof (buffer);
-  res = shishi_a2d (handle, a, buffer, &n);
+  /* shishi_asn1_to_der */
+  res = shishi_asn1_to_der (handle, a, &buf, &n);
   if (res == SHISHI_OK)
-    success ("shishi_a2d() OK\n");
+    success ("shishi_asn1_to_der() OK\n");
   else
-    n = 0, fail ("shishi_a2d() failed\n");
+    n = 0, fail ("shishi_asn1_to_der() failed\n");
   if (debug)
     {
       shishi_authenticator_print (handle, stdout, a);
-      hexprint (buffer, n);
+      hexprint (buf, n);
       puts ("");
       hexprint (authenticator2, sizeof (authenticator2));
       puts ("");
     }
   if (n == sizeof (authenticator2) &&
-      n == AUTHENTICATOR2_LEN && memcmp (authenticator2, buffer, n) == 0)
+      n == AUTHENTICATOR2_LEN && memcmp (authenticator2, buf, n) == 0)
     success ("DER comparison OK\n");
   else
     fail ("DER comparison failed\n");
 
+  free (buf);
+
   /* unlink */
   res = unlink ("authenticator.tmp");
   if (res == 0)
